@@ -1,8 +1,6 @@
 import numpy as np
 import pandas as pd
 import copy
-from matplotlib import pyplot as plt
-from matplotlib.colors import rgb2hex
 import svgwrite
 from pm4py.objects.log.importer.xes import importer as xes_importer
 
@@ -10,13 +8,13 @@ class Vis:
     padding = 5
     square_s = 50
     margin_legend = 30
+    colors = ['#000000','#3b156e','#8b2d80','#dc4b6a','#fc9f72']
+    other_color = '#eeeeee'
 
-    def __init__(self, max_n_color=6, legend=None, mapping_name=None, title=None, width_in_block=20):
+    def __init__(self, legend=None, mapping_name=None, title=None, width_in_block=20):
         """
         Produce SVG visualizations for event logs
         :param seqs: event logs represented as list of lists
-        :param max_n_color: maximum number of colors, only the {max_n_color}
-                            most appearing activities will have their own color
         :param legend:  For some analysis, it could be useful to have two event logs that
                         shares the same legend (e.g., when doing clustering); i.e.,
                         two visualizations will share the same colors and are hence comparable.
@@ -37,7 +35,7 @@ class Vis:
                                 be truncated like [1,2,3,4,5,...,10] (with width_in_block=7)
         """
         self.seqs = None
-        self.max_n_color = int(max_n_color)
+        self.max_n_color = len(self.colors)
         self.legend = legend
         self.mapping_name = mapping_name
         self.title = title
@@ -108,11 +106,8 @@ class Vis:
         y = y.sort_values(by=['count','name'], ascending=[False, True])
 
         # Assign color
-        n_color = min(self.max_n_color, y.shape[0])
-        palette = plt.get_cmap('magma', n_color+1)
-        colors = [rgb2hex(palette(x)) for x in range(n_color)]
-        y['color'] = colors[-1]
-        y.loc[y.iloc[0:n_color].index, 'color'] = colors
+        y['color'] = self.other_color
+        y.loc[y.iloc[:self.max_n_color].index, 'color'] = self.colors[:y.shape[0]]
 
         # Map potential name
         mapping = {x:x for x in y['name'].tolist()}
@@ -126,8 +121,10 @@ class Vis:
         y['ranking'] = np.arange(y.shape[0])
 
         if y.shape[0] > self.max_n_color:
-            y.loc[y.iloc[n_color-1:].index, 'name'] = '+ {} others...'.format(y.shape[0]-n_color+1)
-            y.loc[y.iloc[n_color-1:].index, 'color'] = '#eee'
+            n_other = y.shape[0]-self.max_n_color
+            if n_other>1:
+                y.loc[y.iloc[self.max_n_color:].index, 'name'] = '+ {} others...'.format(n_other)
+            y.loc[y.iloc[self.max_n_color:].index, 'color'] = self.other_color
         return y.to_dict(orient='index')
 
     def _build_svg(self, type):
@@ -189,7 +186,7 @@ class Vis:
             top += self.title is not None
 
             for i, v in enumerate(self.legend.values()):
-                if v['ranking']>=self.max_n_color:
+                if v['ranking']>=self.max_n_color+1:
                     continue
                 t = (self.square_s + self.padding)*(v['ranking']+top)
                 if type == 'seqlegend':
